% M.m
% This function returns the real and imaginary parts of M given by (30)in 
% the "EB_damping" dated on Nov, 1 2007.
%
% Author: Noemi Zakarias
% Date: 11/08/2007

function [ reM, imM ] = M( params, tx, ty )

    [I1Re, I1Im] = fI1(params, tx, ty);
    reM = C(params)* I1Re;
    imM = C(params)* I1Im;

end

%fI1 computes the integral int_0^L fRe*Phi dy 
function [fIre, fIim] = fI1(params, tx, ty)
    precis = params.int_precision;       
    
    fhandle1 = @(y)(fRe(params, y, tx, ty).*Phi0(params, y));
    fIre = quad(fhandle1, 0, params.L, precis);

    fhandle2 = @(y)(fIm(params, y, tx, ty).*Phi0(params, y));
    fIim = quad(fhandle2, 0, params.L, precis);
end

function [ out ] = C(params)
    precis = params.int_precision;    
    L      = params.L;
    ro     = params.ro;
    A      = params.A;
    
    fhandle = @(y)(Phi0(params, y).*Phi0(params, y));
    IntPhisq = quad(fhandle, eps, L, precis);
   
    out = (1/(ro*A)) * (1/IntPhisq);
end

% This function returns the real part of f given by (19)in the "EB_damping"
% Author: Noemi Zakarias
% Date: 11/08/2007
function [ fReout ] = fRe( params, y, tx, ty )

    % T, x0, x1,  are fields in params struct
    T  = params.T;
    x0 = params.x0;
    x1 = params.x1;
    fReout = T*( f1(params, sqrt((x0-tx).*(x0-tx)+(y-ty).*(y-ty))) - ...
                 f1(params, sqrt((x1-tx).*(x1-tx)+(y-ty).*(y-ty))));
end

% This function returns the imaginary part of f given by (19)in the "EB_damping" 
% Author: Noemi Zakarias
% Date: 11/08/2007
function [ fImout ] = fIm(params, y, tx, ty )

    % T, x0, x1,  are fields in params struct
    T  = params.T;
    x0 = params.x0;
    x1 = params.x1;

    fImout = -T*( f2(params, sqrt((x0-tx).*(x0-tx)+(y-ty).*(y-ty))) - ...
                  f2(params, sqrt((x1-tx).*(x1-tx)+(y-ty).*(y-ty))));
end

% This function implements the expression of f1 given by (22) in the "Wave
% Equation in cylindrical coordinates" dated on July, 17 2007
% Author: Noemi Zakarias
% Date: 08/01/2007
function [ f1out ] = f1( params, r)

    %parameters aliases
    k     = params.k;
    c     = params.c;
    %Is alpha already computed?
    if isfield(params, 'alpha')
      alpha = params.alpha;
    else %compute alpha
      alpha = fAlpha(params, 1.0e-6);
    end
    rec1 = fRec1(params, r);
    imc1 = fImc1(params, r);
    
    f1out = (alpha + rec1) .* besselj(0, k*r) - imc1 .* bessely(0, k*r);
    %f1out = pi*f1out/c/c * 0.5;
    %f1out = f1out;
end

% This function implements the expression of f2 given by (23) in the "Wave
% Equation in cylindrical coordinates" dated on July, 17 2007
% Author: Noemi Zakarias
% Date: 08/01/2007
function [ f2out ] = f2( params, r )

    k = params.k;
    c = params.c;
    %Is beta already computed?
    if isfield(params, 'beta')
      beta = params.beta;
    else %compute alpha
      beta = fBeta(params, 1.0e-6);
    end

    %f2out = -pi*beta*besselj(0, k*r)/c/c * 0.5;
    f2out = -beta*besselj(0, k*r);
end




