function [ Imc1out ] = fImc1( params, r )

  [m,n]=size(r);
  %preallocate fImc1
  Imc1out = zeros(m,n);

  for i=1:m
    for j=1:n
      Imc1out(i,j) = fImc1s(params, r(i,j));
    end
  end
end


%scalar version of the function
% fRec1.m
% This function returns the integral for Im(c1) given by (10)in the "Wave
% Equation in cylindrical coordinates" dated on July, 17 2007
%
% Author: Noemi Zakarias
% Date: 08/01/2007

function Imc1sout = fImc1s(params, rs)
  %params aliases
  precis= params.int_precision;
  
  %handle to integrand
  fhandle = @(s)integrnd(s, params);
  %compute the int_0^rs
  Imc1sout = quad(fhandle, eps, rs, precis);
end

%integrand function
function out = integrnd(s, params)
  %params aliases
  sigma = params.sigma;
  k     = params.k;
  two_sigma_square = 2*sigma*sigma;
  
  out = params.scale*s.*(besselj(0,k*s).*exp(-s.*s/two_sigma_square));
end  
